pub struct RenderAssetBytesPerFrame {
pub max_bytes: Option<usize>,
}Expand description
A resource that defines the amount of data allowed to be transferred from CPU to GPU each frame, preventing choppy frames at the cost of waiting longer for GPU assets to become available.
Fields
max_bytes: Option<usize>Implementations
Sourceimpl RenderAssetBytesPerFrame
impl RenderAssetBytesPerFrame
Sourcepub fn new(max_bytes: usize) -> Self
pub fn new(max_bytes: usize) -> Self
max_bytes: the number of bytes to write per frame.
This is a soft limit: only full assets are written currently, uploading stops after the first asset that exceeds the limit.
To participate, assets should implement RenderAsset::byte_len. If the default
is not overridden, the assets are assumed to be small enough to upload without restriction.