pub struct RenderAssetBytesPerFrameLimiter {
pub max_bytes: Option<usize>,
pub bytes_written: AtomicUsize,
}Expand description
A render-world resource that facilitates limiting the data transferred from CPU to GPU each frame, preventing choppy frames at the cost of waiting longer for GPU assets to become available.
Fields
max_bytes: Option<usize>Populated by RenderAssetBytesPerFrame during extraction.
bytes_written: AtomicUsizeBytes written this frame.
Implementations
Sourceimpl RenderAssetBytesPerFrameLimiter
impl RenderAssetBytesPerFrameLimiter
Sourcepub fn reset(&mut self)
pub fn reset(&mut self)
Reset the available bytes. Called once per frame during extraction by crate::RenderPlugin.
Sourcepub fn available_bytes(&self, required_bytes: usize) -> usize
pub fn available_bytes(&self, required_bytes: usize) -> usize
Check how many bytes are available for writing.